<?php
require_once 'database.php';
session_start();

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['success' => false, 'message' => 'Unauthorized access']);
    exit();
}

// Function to log user activity
function logUserActivity($user_id, $action, $details) {
    $db = new Database();
    $conn = $db->connect();
    
    $stmt = $conn->prepare("INSERT INTO user_activity_log (user_id, action, details) VALUES (?, ?, ?)");
    $stmt->execute([$user_id, $action, $details]);
}

// Handle POST request
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $response = ['success' => false, 'message' => ''];
    
    try {
        // Validate input
        $required_fields = ['table', 'date', 'phone', 'email', 'bank', 'prix', 'cost', 'status'];
        foreach ($required_fields as $field) {
            if (!isset($_POST[$field]) || empty($_POST[$field])) {
                throw new Exception("Missing required field: $field");
            }
        }
        
        $table = $_POST['table'];
        if (!in_array($table, ['canva', 'pack', 'office'])) {
            throw new Exception('Invalid table specified');
        }
        
        // Clean and prepare data
        $data = [
            'date' => $_POST['date'],
            'phone' => $_POST['phone'],
            'email' => $_POST['email'],
            'bank' => $_POST['bank'],
            'prix' => floatval($_POST['prix']),
            'cost' => floatval($_POST['cost']),
            'status' => $_POST['status']
        ];
        
        // Insert into database
        $db = new Database();
        $conn = $db->connect();
        
        $columns = implode(', ', array_keys($data));
        $values = implode(', ', array_fill(0, count($data), '?'));
        
        $sql = "INSERT INTO $table ($columns) VALUES ($values)";
        $stmt = $conn->prepare($sql);
        
        if ($stmt->execute(array_values($data))) {
            // Log the activity
            logUserActivity($_SESSION['user_id'], 'add_order', "Added new order to $table");
            
            $response = [
                'success' => true,
                'message' => 'Order added successfully'
            ];
        } else {
            throw new Exception('Failed to add order');
        }
        
    } catch (Exception $e) {
        $response = [
            'success' => false,
            'message' => $e->getMessage()
        ];
    }
    
    // Return JSON response
    header('Content-Type: application/json');
    echo json_encode($response);
    exit();
} 