<?php
require_once 'database.php';

try {
    $db = new Database();
    $conn = $db->connect();

    // Default credentials
    $users = [
        [
            'username' => 'admin',
            'password' => password_hash('password', PASSWORD_DEFAULT),
            'role' => 'admin'
        ],
        [
            'username' => 'user',
            'password' => password_hash('password', PASSWORD_DEFAULT),
            'role' => 'user'
        ]
    ];

    // Check if users already exist
    foreach ($users as $user) {
        $stmt = $conn->prepare("SELECT id FROM users WHERE username = ?");
        $stmt->execute([$user['username']]);
        
        if (!$stmt->fetch()) {
            // User doesn't exist, create it
            $stmt = $conn->prepare("INSERT INTO users (username, password, role) VALUES (?, ?, ?)");
            if ($stmt->execute([$user['username'], $user['password'], $user['role']])) {
                echo "Created {$user['role']} account with username: {$user['username']}\n";
            } else {
                echo "Failed to create {$user['role']} account\n";
            }
        } else {
            echo "User {$user['username']} already exists\n";
        }
    }

    echo "\nDefault credentials:\n";
    echo "Admin - username: admin, password: password\n";
    echo "User  - username: user, password: password\n";

} catch (PDOException $e) {
    echo "Database error: " . $e->getMessage() . "\n";
}
?>