<?php
require_once 'database.php';

try {
    $db = new Database();
    $conn = $db->connect();

    // First, let's check the structure of our tables
    $tables = ['canva', 'pack', 'office'];
    $columns = [];
    
    foreach ($tables as $table) {
        $stmt = $conn->query("DESCRIBE $table");
        $columns[$table] = $stmt->fetchAll(PDO::FETCH_COLUMN);
        echo "Columns in $table table: " . implode(", ", $columns[$table]) . "\n";
    }

    // Drop the view if it exists
    $conn->exec("DROP VIEW IF EXISTS combined_orders");

    // Create the combined view with column existence checks
    $sql = "CREATE VIEW combined_orders AS\n";
    
    $union = "";
    foreach ($tables as $table) {
        $sql .= $union;
        $sql .= "SELECT 
            '$table' as source,
            id as order_id,
            " . (in_array('date', $columns[$table]) ? 'date,' : 'NOW() as date,') . "
            " . (in_array('phone', $columns[$table]) ? 'phone,' : 'NULL as phone,') . "
            " . (in_array('email', $columns[$table]) ? 'email,' : 'NULL as email,') . "
            " . (in_array('bank', $columns[$table]) ? 'bank,' : 'NULL as bank,') . "
            " . (in_array('prix', $columns[$table]) ? 'prix' : '0.00') . " as amount,
            " . (in_array('status', $columns[$table]) ? "COALESCE(status, 'pending')" : "'pending'") . " as status,
            " . (in_array('confirmed', $columns[$table]) ? 'COALESCE(confirmed, 0)' : '0') . " as confirmed,
            " . (in_array('cost', $columns[$table]) ? 'COALESCE(cost, 0.00)' : '0.00') . " as cost,
            " . (in_array('order_id', $columns[$table]) ? 'order_id' : 'id') . " as product_id
        FROM $table";
        $union = "\n\nUNION ALL\n\n";
    }

    echo "\nExecuting SQL:\n" . $sql . "\n";
    
    $conn->exec($sql);
    echo "\nCombined orders view created successfully!";
} catch (PDOException $e) {
    echo "Error creating view: " . $e->getMessage() . "\n";
    echo "SQL State: " . $e->getCode() . "\n";
}
?> 