<?php
session_start();
require_once 'database.php';

if (!isset($_SESSION['user_id'])) {
    http_response_code(401);
    exit('Unauthorized');
}

// Get table parameter and validate
$table = isset($_GET['table']) ? $_GET['table'] : 'canva';
if (!in_array($table, ['canva', 'pack', 'office', 'fb_ads'])) {
    http_response_code(400);
    exit('Invalid table specified');
}

try {
    $db = new Database();
    $conn = $db->connect();

    // Get date range if provided
    $start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '';
    $end_date = isset($_GET['end_date']) ? $_GET['end_date'] : '';

    // Build query
    $sql = "SELECT * FROM $table";
    $params = [];

    if ($start_date && $end_date) {
        $sql .= " WHERE date BETWEEN ? AND ?";
        $params = [$start_date, $end_date];
    }

    $sql .= " ORDER BY date DESC";

    // Execute query
    $stmt = $conn->prepare($sql);
    $stmt->execute($params);
    $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if (empty($results)) {
        http_response_code(404);
        exit('No data found');
    }

    // Set headers for CSV download
    $filename = $table . '_export_' . date('Y-m-d_His') . '.csv';
    header('Content-Type: text/csv');
    header('Content-Disposition: attachment; filename="' . $filename . '"');

    // Create output stream
    $output = fopen('php://output', 'w');

    // Add headers
    fputcsv($output, array_keys($results[0]));

    // Add data
    foreach ($results as $row) {
        fputcsv($output, $row);
    }

    fclose($output);
    exit();

} catch (PDOException $e) {
    http_response_code(500);
    exit('Database error: ' . $e->getMessage());
}
?>