<?php
session_start();
require_once 'database.php';

if (!isset($_SESSION['user_id'])) {
    http_response_code(401);
    exit('Unauthorized');
}

header('Content-Type: application/json');

try {
    $db = new Database();
    $conn = $db->connect();

    // Get counts for each table
    $counts = [
        'canva' => $conn->query("SELECT COUNT(*) FROM canva")->fetchColumn(),
        'pack' => $conn->query("SELECT COUNT(*) FROM pack")->fetchColumn(),
        'office' => $conn->query("SELECT COUNT(*) FROM office")->fetchColumn()
    ];

    // Get sales data for the last 7 days
    $sales_data = [];
    $dates = [];
    for ($i = 6; $i >= 0; $i--) {
        $date = date('Y-m-d', strtotime("-$i days"));
        $dates[] = $date;
        
        // Get sales for each table on this date
        $sales_data['canva'][] = $conn->query("SELECT COUNT(*) FROM canva WHERE DATE(date) = '$date'")->fetchColumn();
        $sales_data['pack'][] = $conn->query("SELECT COUNT(*) FROM pack WHERE DATE(date) = '$date'")->fetchColumn();
        $sales_data['office'][] = $conn->query("SELECT COUNT(*) FROM office WHERE DATE(date) = '$date'")->fetchColumn();
    }

    // Get Facebook Ads data for the last 7 days
    $ads_dates = [];
    $ads_data = [
        'conversations' => [],
        'amount_spent' => []
    ];

    for ($i = 6; $i >= 0; $i--) {
        $date = date('Y-m-d', strtotime("-$i days"));
        $ads_dates[] = $date;
        
        // Get conversations and amount spent for this date
        $ads_query = $conn->prepare("
            SELECT 
                COALESCE(SUM(conversations_started), 0) as total_conversations,
                COALESCE(SUM(amount_spent), 0) as total_spent
            FROM fb_ads 
            WHERE DATE(date) = ?
        ");
        $ads_query->execute([$date]);
        $ads_result = $ads_query->fetch(PDO::FETCH_ASSOC);
        
        $ads_data['conversations'][] = (int)$ads_result['total_conversations'];
        $ads_data['amount_spent'][] = (float)$ads_result['total_spent'];
    }

    // Prepare response
    $response = [
        'canva_count' => $counts['canva'],
        'pack_count' => $counts['pack'],
        'office_count' => $counts['office'],
        'sales_dates' => $dates,
        'canva_sales' => $sales_data['canva'],
        'pack_sales' => $sales_data['pack'],
        'office_sales' => $sales_data['office'],
        'ads_dates' => $ads_dates,
        'conversations' => $ads_data['conversations'],
        'amount_spent' => $ads_data['amount_spent']
    ];

    echo json_encode($response);

} catch (PDOException $e) {
    http_response_code(500);
    echo json_encode(['error' => 'Database error: ' . $e->getMessage()]);
}
?> 