<?php
$page_title = "Dashboard";
$extra_css = '<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>';
require_once 'header.php';
require_once 'database.php';

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$db = new Database();
$conn = $db->connect();
?>

    <div class="row">
        <div class="col-md-12">
            <div class="card">
                <div class="card-body">
                    <h2 class="card-title">Dashboard</h2>
                    <!-- Summary Cards -->
                    <div class="row g-4 mb-4">
                        <div class="col-md-4">
                            <div class="card stats-card h-100">
                                <div class="card-body">
                                    <h5 class="card-title">Canva Orders</h5>
                                    <div class="d-flex align-items-center">
                                        <i class='bx bx-shopping-bag fs-1 me-3 text-primary'></i>
                                        <div>
                                            <h3 class="mb-0" id="canvaCount">Loading...</h3>
                                            <small class="text-muted">Total Orders</small>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="card stats-card h-100">
                                <div class="card-body">
                                    <h5 class="card-title">Pack Orders</h5>
                                    <div class="d-flex align-items-center">
                                        <i class='bx bx-package fs-1 me-3 text-success'></i>
                                        <div>
                                            <h3 class="mb-0" id="packCount">Loading...</h3>
                                            <small class="text-muted">Total Orders</small>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="card stats-card h-100">
                                <div class="card-body">
                                    <h5 class="card-title">Office Orders</h5>
                                    <div class="d-flex align-items-center">
                                        <i class='bx bx-building fs-1 me-3 text-warning'></i>
                                        <div>
                                            <h3 class="mb-0" id="officeCount">Loading...</h3>
                                            <small class="text-muted">Total Orders</small>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Charts -->
                    <div class="row g-4">
                        <div class="col-md-6">
                            <div class="card">
                                <div class="card-body">
                                    <h5 class="card-title">Sales Overview</h5>
                                    <div class="chart-container">
                                        <canvas id="salesChart"></canvas>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="card">
                                <div class="card-body">
                                    <h5 class="card-title">Facebook Ads Performance</h5>
                                    <div class="chart-container">
                                        <canvas id="adsChart"></canvas>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

</div> <!-- Close container from header -->

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
<script>
    // Fetch summary data
    fetch('fetch_summary.php')
        .then(response => response.json())
        .then(data => {
            document.getElementById('canvaCount').textContent = data.canva_count;
            document.getElementById('packCount').textContent = data.pack_count;
            document.getElementById('officeCount').textContent = data.office_count;

            // Sales Chart
            const salesCtx = document.getElementById('salesChart').getContext('2d');
            new Chart(salesCtx, {
                type: 'line',
                data: {
                    labels: data.sales_dates,
                    datasets: [
                        {
                            label: 'Canva',
                            data: data.canva_sales,
                            borderColor: '#0d6efd',
                            tension: 0.1
                        },
                        {
                            label: 'Pack',
                            data: data.pack_sales,
                            borderColor: '#198754',
                            tension: 0.1
                        },
                        {
                            label: 'Office',
                            data: data.office_sales,
                            borderColor: '#ffc107',
                            tension: 0.1
                        }
                    ]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false
                }
            });

            // Ads Chart
            const adsCtx = document.getElementById('adsChart').getContext('2d');
            new Chart(adsCtx, {
                type: 'bar',
                data: {
                    labels: data.ads_dates,
                    datasets: [
                        {
                            label: 'Messages',
                            data: data.conversations,
                            backgroundColor: '#0d6efd'
                        },
                        {
                            label: 'Cost ($)',
                            data: data.amount_spent,
                            backgroundColor: '#198754'
                        }
                    ]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: {
                            beginAtZero: true
                        }
                    }
                }
            });
        })
        .catch(error => console.error('Error fetching data:', error));
</script>
</body>
</html> 