-- User Activity Logs
CREATE TABLE IF NOT EXISTS user_activity_logs (
    id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT NOT NULL,
    action VARCHAR(255) NOT NULL,
    details TEXT,
    ip_address VARCHAR(45),
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE
);

-- Security Logs
CREATE TABLE IF NOT EXISTS security_logs (
    id INT AUTO_INCREMENT PRIMARY KEY,
    type ENUM('login_attempt', 'password_reset', '2fa', 'ip_block') NOT NULL,
    status ENUM('success', 'failure') NOT NULL,
    username VARCHAR(255),
    ip_address VARCHAR(45),
    details TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- System Settings
CREATE TABLE IF NOT EXISTS system_settings (
    id INT AUTO_INCREMENT PRIMARY KEY,
    setting_key VARCHAR(255) NOT NULL UNIQUE,
    setting_value TEXT,
    setting_group VARCHAR(50) NOT NULL,
    description TEXT,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- Product Images
CREATE TABLE IF NOT EXISTS product_images (
    id INT AUTO_INCREMENT PRIMARY KEY,
    product_id INT NOT NULL,
    image_path VARCHAR(255) NOT NULL,
    is_primary BOOLEAN DEFAULT FALSE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (product_id) REFERENCES products(id) ON DELETE CASCADE
);

-- Product Inventory
CREATE TABLE IF NOT EXISTS product_inventory (
    id INT AUTO_INCREMENT PRIMARY KEY,
    product_id INT NOT NULL,
    quantity INT NOT NULL DEFAULT 0,
    last_restock_date TIMESTAMP,
    reorder_point INT DEFAULT 10,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (product_id) REFERENCES products(id) ON DELETE CASCADE
);

-- Insert default system settings
INSERT INTO system_settings (setting_key, setting_value, setting_group, description) VALUES
('site_name', 'Order & Ads Analytics', 'general', 'Website name'),
('admin_email', 'admin@example.com', 'general', 'Admin email address'),
('enable_2fa', '0', 'security', 'Enable two-factor authentication'),
('max_login_attempts', '5', 'security', 'Maximum login attempts before account lock'),
('lock_duration', '30', 'security', 'Account lock duration in minutes'),
('currency', 'USD', 'general', 'Default currency'),
('date_format', 'Y-m-d', 'general', 'Default date format'),
('items_per_page', '10', 'general', 'Number of items to show per page'),
('backup_enabled', '1', 'system', 'Enable automatic backups'),
('backup_frequency', 'daily', 'system', 'Backup frequency'); 