-- Create canva table
CREATE TABLE IF NOT EXISTS canva (
    id INT AUTO_INCREMENT PRIMARY KEY,
    date DATE NOT NULL,
    phone VARCHAR(20) NOT NULL,
    email VARCHAR(255),
    bank VARCHAR(50) NOT NULL,
    prix DECIMAL(10,2) NOT NULL,
    status VARCHAR(20) DEFAULT 'pending',
    confirmed TINYINT(1) DEFAULT 0,
    cost DECIMAL(10,2) DEFAULT 0.00,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Create pack table
CREATE TABLE IF NOT EXISTS pack (
    id INT AUTO_INCREMENT PRIMARY KEY,
    date DATE NOT NULL,
    phone VARCHAR(20) NOT NULL,
    email VARCHAR(255),
    bank VARCHAR(50) NOT NULL,
    prix DECIMAL(10,2) NOT NULL,
    status VARCHAR(20) DEFAULT 'pending',
    confirmed TINYINT(1) DEFAULT 0,
    cost DECIMAL(10,2) DEFAULT 0.00,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Create office table
CREATE TABLE IF NOT EXISTS office (
    id INT AUTO_INCREMENT PRIMARY KEY,
    date DATE NOT NULL,
    phone VARCHAR(20) NOT NULL,
    email VARCHAR(255),
    bank VARCHAR(50) NOT NULL,
    prix DECIMAL(10,2) NOT NULL,
    status VARCHAR(20) DEFAULT 'pending',
    confirmed TINYINT(1) DEFAULT 0,
    cost DECIMAL(10,2) DEFAULT 0.00,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Create products table
CREATE TABLE IF NOT EXISTS products (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    price DECIMAL(10,2) NOT NULL,
    category ENUM('canva', 'pack', 'office') NOT NULL,
    description TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
);

-- Create user_activity_log table
CREATE TABLE IF NOT EXISTS user_activity_log (
    id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT NOT NULL,
    action VARCHAR(50) NOT NULL,
    details TEXT,
    ip_address VARCHAR(45),
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id)
);

-- Create security_log table
CREATE TABLE IF NOT EXISTS security_log (
    id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT,
    action VARCHAR(50) NOT NULL,
    status ENUM('success', 'failed') NOT NULL,
    ip_address VARCHAR(45),
    details TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id)
);

-- Create system_settings table
CREATE TABLE IF NOT EXISTS system_settings (
    id INT AUTO_INCREMENT PRIMARY KEY,
    setting_key VARCHAR(50) NOT NULL UNIQUE,
    setting_value TEXT,
    description TEXT,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
);

-- Insert default system settings
INSERT INTO system_settings (setting_key, setting_value, description) VALUES
('site_name', 'Order Management System', 'The name of the website'),
('admin_email', 'admin@example.com', 'Admin email address'),
('enable_two_factor', '0', 'Enable two-factor authentication'),
('session_timeout', '30', 'Session timeout in minutes'),
('enable_email_notifications', '1', 'Enable email notifications'),
('backup_frequency', 'daily', 'Database backup frequency'),
('last_backup', NULL, 'Last backup timestamp'),
('maintenance_mode', '0', 'Maintenance mode status'),
('max_login_attempts', '5', 'Maximum login attempts before lockout'),
('lockout_duration', '30', 'Account lockout duration in minutes');

-- Create product_images table
CREATE TABLE IF NOT EXISTS product_images (
    id INT AUTO_INCREMENT PRIMARY KEY,
    product_id INT NOT NULL,
    image_url VARCHAR(255) NOT NULL,
    is_primary TINYINT(1) DEFAULT 0,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (product_id) REFERENCES products(id)
);

-- Create product_inventory table
CREATE TABLE IF NOT EXISTS product_inventory (
    id INT AUTO_INCREMENT PRIMARY KEY,
    product_id INT NOT NULL,
    quantity INT NOT NULL DEFAULT 0,
    reorder_point INT NOT NULL DEFAULT 5,
    last_restocked DATE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (product_id) REFERENCES products(id)
);

-- Create combined_orders view
CREATE OR REPLACE VIEW combined_orders AS
SELECT 
    'canva' as source,
    id,
    date,
    phone,
    email,
    bank,
    prix as amount,
    cost,
    COALESCE(status, 'pending') as status,
    confirmed
FROM canva
UNION ALL
SELECT 
    'pack' as source,
    id,
    date,
    phone,
    email,
    bank,
    prix as amount,
    cost,
    COALESCE(status, 'pending') as status,
    confirmed
FROM pack
UNION ALL
SELECT 
    'office' as source,
    id,
    date,
    phone,
    email,
    bank,
    prix as amount,
    cost,
    COALESCE(status, 'pending') as status,
    confirmed
FROM office; 