<?php
$page_title = "Upload Data";
require_once 'header.php';
require_once 'database.php';

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$error = '';
$success = '';
$preview_data = [];
$headers = [];
$table = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_FILES['csv_file']) && $_FILES['csv_file']['error'] === UPLOAD_ERR_OK) {
        $table = $_POST['table'];
        
        // Validate table name
        if (!in_array($table, ['canva', 'pack', 'office', 'fb_ads'])) {
            $error = "Invalid table selection.";
        } else {
            $file = $_FILES['csv_file']['tmp_name'];
            
            // Read CSV file
            if (($handle = fopen($file, "r")) !== FALSE) {
                $headers = fgetcsv($handle);
                
                // Validate headers based on table
                $required_headers = [
                    'canva' => ['Date', 'Order Id', 'whatsapp', 'Email', 'Bank', 'Order', 'Price', 'Confirmed', 'cost'],
                    'pack' => ['Date', 'Order Id', 'whatsapp', 'Email', 'Bank', 'Order', 'Price', 'Confirmed', 'cost'],
                    'office' => ['Date', 'Order Id', 'whatsapp', 'Email', 'Bank', 'Order', 'Price', 'Confirmed', 'cost'],
                    'fb_ads' => ['Campaign name', 'Campaign ID', 'Date', 'CPM (cost per 1,000 impressions)', 'CTR (all)', 'Impressions', 'Reach', 'Amount spent', 'Link clicks', 'Messaging conversations started']
                ];

                $missing_headers = array_diff($required_headers[$table], $headers);
                
                if (!empty($missing_headers)) {
                    $error = "Missing required columns: " . implode(", ", $missing_headers);
                } else {
                    // Store all CSV data
                    $all_data = [];
                    rewind($handle); // Go back to start of file
                    $headers = fgetcsv($handle); // Read headers again

                    // Map headers to database columns
                    $header_mapping = [];
                    if ($table === 'fb_ads') {
                        $header_mapping = [
                            'Campaign name' => 'campaign_name',
                            'Campaign ID' => 'campaign_id',
                            'Date' => 'date',
                            'CPM (cost per 1,000 impressions)' => 'cpm',
                            'CTR (all)' => 'ctr',
                            'Impressions' => 'impressions',
                            'Reach' => 'reach',
                            'Amount spent' => 'amount_spent',
                            'Link clicks' => 'link_clicks',
                            'Messaging conversations started' => 'conversations_started'
                        ];

                        // Log headers for debugging
                        error_log("CSV Headers: " . implode(", ", $headers));
                        error_log("Expected Headers: " . implode(", ", array_keys($header_mapping)));
                    } else {
                        // Mapping for canva, pack, and office tables
                        $header_mapping = [
                            'Date' => 'date',
                            'Order Id' => 'msg_id',
                            'whatsapp' => 'phone',
                            'Email' => 'email',
                            'Bank' => 'bank',
                            'Order' => 'product',
                            'Price' => 'prix',
                            'Confirmed' => 'confirmed',
                            'cost' => 'cost'
                        ];
                    }

                    while (($row = fgetcsv($handle)) !== FALSE) {
                        $all_data[] = $row;
                    }

                    // Store data in session
                    $_SESSION['upload_data'] = [
                        'table' => $table,
                        'headers' => $headers,
                        'data' => $all_data,
                        'header_mapping' => $header_mapping
                    ];

                    // Preview first 5 rows
                    $preview_data = [];
                    for ($i = 0; $i < min(5, count($all_data)); $i++) {
                        $row = $all_data[$i];
                        $mapped_row = [];
                        foreach ($row as $index => $value) {
                            if (isset($headers[$index]) && !empty($headers[$index])) {
                                $original_header = $headers[$index];
                                if (isset($header_mapping[$original_header])) {
                                    $db_column = $header_mapping[$original_header];
                                    $mapped_row[$db_column] = $value;
                                } else {
                                    error_log("Warning: No mapping found for header: " . $original_header);
                                }
                            } else {
                                error_log("Warning: Empty or missing header at index: " . $index);
                            }
                        }
                        $preview_data[] = $mapped_row;
                    }
                }
                fclose($handle);
            } else {
                $error = "Failed to read CSV file.";
            }
        }
    } elseif (isset($_POST['confirm_upload']) && isset($_SESSION['upload_data'])) {
        $upload_data = $_SESSION['upload_data'];
        $table = $upload_data['table'];
        $headers = $upload_data['headers'];
        $all_data = $upload_data['data'];
        $header_mapping = $upload_data['header_mapping'];
        
        $db = new Database();
        $conn = $db->connect();
        
        $success_count = 0;
        $error_count = 0;

        foreach ($all_data as $row) {
            try {
                // Map the data using the header mapping
                $mapped_data = [];
                foreach ($row as $index => $value) {
                    if (isset($headers[$index]) && !empty($headers[$index])) {
                        $original_header = $headers[$index];
                        if (isset($header_mapping[$original_header])) {
                            $db_column = $header_mapping[$original_header];
                            
                            // Convert numeric values and clean data
                            switch ($db_column) {
                                case 'prix':
                                case 'cost':
                                    $value = str_replace(['$', ',', '%'], '', trim($value));
                                    $value = $value === '' ? 0 : floatval($value);
                                    break;
                                case 'cpm':
                                case 'amount_spent':
                                    $value = floatval(str_replace(['$', ',', '%'], '', $value));
                                    break;
                                case 'impressions':
                                case 'reach':
                                case 'link_clicks':
                                case 'conversations_started':
                                    $value = intval(str_replace(',', '', $value));
                                    break;
                                case 'confirmed':
                                    $value = strtolower(trim($value)) === 'yes' ? 1 : 0;
                                    break;
                                case 'date':
                                    // Try to parse and standardize the date format
                                    $value = trim($value);
                                    $date = date_create_from_format('Y-m-d', $value) ?: 
                                           date_create_from_format('d/m/Y', $value) ?: 
                                           date_create_from_format('m/d/Y', $value) ?:
                                           date_create_from_format('Y/m/d', $value);
                                    
                                    if (!$date) {
                                        error_log("Date parsing failed for value: " . $value);
                                        throw new Exception("Invalid date format: " . $value);
                                    }

                                    // Validate that the date is not in the future
                                    $today = new DateTime();
                                    $today->setTime(0, 0, 0);
                                    if ($date > $today) {
                                        error_log("Future date detected: " . $value);
                                        throw new Exception("Date cannot be in the future: " . $value);
                                    }

                                    // Validate that the date is not too old (e.g., more than 2 years ago)
                                    $twoYearsAgo = new DateTime();
                                    $twoYearsAgo->modify('-2 years');
                                    $twoYearsAgo->setTime(0, 0, 0);
                                    if ($date < $twoYearsAgo) {
                                        error_log("Date too old: " . $value);
                                        throw new Exception("Date is too old (more than 2 years): " . $value);
                                    }

                                    $value = $date->format('Y-m-d');
                                    break;
                                default:
                                    $value = trim($value);
                                    break;
                            }
                            
                            $mapped_data[$db_column] = $value;
                        } else {
                            error_log("Warning: No mapping found for header: " . $original_header);
                        }
                    } else {
                        error_log("Warning: Empty or missing header at index: " . $index);
                    }
                }

                if (empty($mapped_data)) {
                    throw new Exception("No valid data to insert after mapping");
                }

                // Debug log the mapped data
                error_log("Attempting to insert row: " . json_encode($mapped_data));

                $columns = implode(", ", array_keys($mapped_data));
                $values = implode(", ", array_fill(0, count($mapped_data), "?"));
                $sql = "INSERT INTO $table ($columns) VALUES ($values)";
                
                try {
                    $stmt = $conn->prepare($sql);
                    if ($stmt->execute(array_values($mapped_data))) {
                        $success_count++;
                    } else {
                        $error_count++;
                        $error_info = $stmt->errorInfo();
                        error_log("SQL Error: " . json_encode($error_info));
                    }
                } catch (PDOException $e) {
                    $error_count++;
                    error_log("PDO Error: " . $e->getMessage());
                    error_log("SQL: " . $sql);
                    error_log("Data: " . json_encode(array_values($mapped_data)));
                }
            } catch (Exception $e) {
                $error_count++;
                error_log("Data Processing Error: " . $e->getMessage());
            }
        }
        
        // Clear the upload data from session
        unset($_SESSION['upload_data']);
        
        $success = "Upload completed: $success_count records inserted successfully, $error_count failed.";
    }
}
?>

    <div class="card">
        <div class="card-body">
            <h2 class="card-title mb-4">Upload CSV Data</h2>
            
            <?php if ($error): ?>
                <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
            <?php endif; ?>
            
            <?php if ($success): ?>
                <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
            <?php endif; ?>

            <?php if (empty($preview_data)): ?>
                <form method="POST" enctype="multipart/form-data" class="mb-4">
                    <div class="mb-3">
                        <label for="table" class="form-label">Select Table</label>
                        <select class="form-select" id="table" name="table" required>
                            <option value="">Choose table...</option>
                            <option value="canva">Canva Orders</option>
                            <option value="pack">Pack Orders</option>
                            <option value="office">Office Orders</option>
                            <option value="fb_ads">Facebook Ads Data</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label for="csv_file" class="form-label">Upload CSV File</label>
                        <input type="file" class="form-control" id="csv_file" name="csv_file" accept=".csv" required>
                        <div class="form-text">
                            Required headers for orders: Date, Order Id, whatsapp, Email, Bank, Order, Price, Confirmed, cost<br>
                            Required headers for FB Ads: Campaign name, Campaign ID, Date, CPM (cost per 1,000 impressions), CTR (all), Impressions, Reach, Amount spent, Link clicks, Messaging conversations started
                        </div>
                    </div>
                    <button type="submit" class="btn btn-primary">Preview Data</button>
                </form>
            <?php else: ?>
                <h4 class="mb-3">Preview Data</h4>
                <div class="table-responsive mb-4">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <?php foreach ($headers as $header): ?>
                                    <?php if (!empty($header)): ?>
                                    <th><?php echo htmlspecialchars($header); ?></th>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($preview_data as $row): ?>
                                <tr>
                                    <?php foreach ($headers as $header): ?>
                                        <?php if (!empty($header) && isset($header_mapping[$header]) && isset($row[$header_mapping[$header]])): ?>
                                        <td><?php echo htmlspecialchars($row[$header_mapping[$header]]); ?></td>
                                        <?php else: ?>
                                        <td></td>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
                <form method="POST" class="mb-4">
                    <input type="hidden" name="confirm_upload" value="1">
                    <button type="submit" class="btn btn-success">Confirm Upload</button>
                    <a href="upload.php" class="btn btn-secondary">Cancel</a>
                </form>
            <?php endif; ?>
        </div>
    </div>

</div> <!-- Close container from header -->

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html> 