<?php
$page_title = "View Orders";
require_once 'header.php';
require_once 'database.php';

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$db = new Database();
$conn = $db->connect();

$success_message = '';
$error_message = '';

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'edit_order':
                $order_id = $_POST['order_id'];
                $table = $_POST['table'];
                $phone = $_POST['phone'];
                $email = $_POST['email'];
                $bank = $_POST['bank'];
                $prix = $_POST['prix'];
                
                try {
                    $stmt = $conn->prepare("UPDATE $table SET phone = ?, email = ?, bank = ?, prix = ? WHERE id = ?");
                    $stmt->execute([$phone, $email, $bank, $prix, $order_id]);
                    $success_message = "Order updated successfully";
                } catch (PDOException $e) {
                    $error_message = "Error updating order: " . $e->getMessage();
                }
                break;

            case 'delete_order':
                $order_id = $_POST['order_id'];
                $table = $_POST['table'];
                
                try {
                    $stmt = $conn->prepare("DELETE FROM $table WHERE id = ?");
                    $stmt->execute([$order_id]);
                    $success_message = "Order deleted successfully";
                } catch (PDOException $e) {
                    $error_message = "Error deleting order: " . $e->getMessage();
                }
                break;
        }
    }
}

// Get parameters
$table = isset($_GET['table']) ? $_GET['table'] : 'canva';
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : '';
$per_page = 10;

// Validate table name
if (!in_array($table, ['canva', 'pack', 'office'])) {
    $table = 'canva';
}

// Build query
$where_conditions = [];
$params = [];

if ($search) {
    $where_conditions[] = "(phone LIKE ? OR email LIKE ?)";
    $search_param = "%$search%";
    $params = array_merge($params, [$search_param, $search_param]);
}

if ($start_date) {
    $where_conditions[] = "date >= ?";
    $params[] = $start_date;
}

if ($end_date) {
    $where_conditions[] = "date <= ?";
    $params[] = $end_date;
}

$where_clause = $where_conditions ? 'WHERE ' . implode(' AND ', $where_conditions) : '';

// Get total records
$count_sql = "SELECT COUNT(*) as total FROM $table $where_clause";
$stmt = $conn->prepare($count_sql);
$stmt->execute($params);
$total_records = $stmt->fetch()['total'];
$total_pages = ceil($total_records / $per_page);

// Ensure page is within valid range
$page = max(1, min($page, $total_pages));
$offset = ($page - 1) * $per_page;

// Get records - Fixed the LIMIT and OFFSET binding
$sql = "SELECT * FROM $table $where_clause ORDER BY date DESC LIMIT " . (int)$offset . ", " . (int)$per_page;
$stmt = $conn->prepare($sql);

// Execute with only the WHERE clause parameters
$stmt->execute($params);
$orders = $stmt->fetchAll();
?>

    <div class="card">
        <div class="card-body">
            <h2 class="card-title mb-4">View Orders</h2>
            
            <!-- Table Selection -->
            <div class="mb-4">
                <div class="btn-group" role="group">
                    <a href="?table=canva" class="btn btn-<?php echo $table === 'canva' ? 'primary' : 'outline-primary'; ?>">Canva Orders</a>
                    <a href="?table=pack" class="btn btn-<?php echo $table === 'pack' ? 'primary' : 'outline-primary'; ?>">Pack Orders</a>
                    <a href="?table=office" class="btn btn-<?php echo $table === 'office' ? 'primary' : 'outline-primary'; ?>">Office Orders</a>
                </div>
            </div>

            <!-- Search and Filter -->
            <form class="row g-3 mb-4">
                <input type="hidden" name="table" value="<?php echo htmlspecialchars($table); ?>">
                <div class="col-md-4">
                    <input type="text" class="form-control" name="search" placeholder="Search by phone or email" value="<?php echo htmlspecialchars($search); ?>">
                </div>
                <div class="col-md-3">
                    <input type="date" class="form-control" name="start_date" value="<?php echo htmlspecialchars($start_date); ?>">
                </div>
                <div class="col-md-3">
                    <input type="date" class="form-control" name="end_date" value="<?php echo htmlspecialchars($end_date); ?>">
                </div>
                <div class="col-md-2">
                    <button type="submit" class="btn btn-primary w-100">Filter</button>
                </div>
            </form>

            <!-- Orders Table -->
            <div class="table-responsive">
                <table class="table table-hover">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Phone</th>
                            <th>Email</th>
                            <th>Product</th>
                            <th>Price</th>
                            <th>Bank</th>
                            <th>Date</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($orders as $order): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($order['id']); ?></td>
                            <td><?php echo htmlspecialchars($order['phone']); ?></td>
                            <td><?php echo htmlspecialchars($order['email']); ?></td>
                            <td><?php echo htmlspecialchars($order['product']); ?></td>
                            <td><?php echo htmlspecialchars($order['prix']); ?></td>
                            <td><?php echo htmlspecialchars($order['bank']); ?></td>
                            <td><?php echo htmlspecialchars($order['date']); ?></td>
                            <td>
                                <button type="button" class="btn btn-primary btn-sm" data-bs-toggle="modal" data-bs-target="#editOrder<?php echo $order['id'] . $table; ?>">
                                    Edit
                                </button>
                                <button type="button" class="btn btn-danger btn-sm" data-bs-toggle="modal" data-bs-target="#deleteOrder<?php echo $order['id'] . $table; ?>">
                                    Delete
                                </button>
                            </td>
                        </tr>

                        <!-- Edit Modal -->
                        <div class="modal fade" id="editOrder<?php echo $order['id'] . $table; ?>" tabindex="-1">
                            <div class="modal-dialog">
                                <div class="modal-content">
                                    <div class="modal-header">
                                        <h5 class="modal-title">Edit Order #<?php echo $order['id']; ?></h5>
                                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                                    </div>
                                    <form method="POST">
                                        <div class="modal-body">
                                            <input type="hidden" name="action" value="edit_order">
                                            <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                            <input type="hidden" name="table" value="<?php echo $table; ?>">
                                            
                                            <div class="mb-3">
                                                <label class="form-label">Phone</label>
                                                <input type="text" name="phone" class="form-control" value="<?php echo htmlspecialchars($order['phone']); ?>" required>
                                            </div>
                                            <div class="mb-3">
                                                <label class="form-label">Email</label>
                                                <input type="email" name="email" class="form-control" value="<?php echo htmlspecialchars($order['email']); ?>" required>
                                            </div>
                                            <div class="mb-3">
                                                <label class="form-label">Bank</label>
                                                <input type="text" name="bank" class="form-control" value="<?php echo htmlspecialchars($order['bank']); ?>" required>
                                            </div>
                                            <div class="mb-3">
                                                <label class="form-label">Amount</label>
                                                <input type="number" name="prix" class="form-control" value="<?php echo $order['prix']; ?>" step="0.01" required>
                                            </div>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                                            <button type="submit" class="btn btn-primary">Save Changes</button>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>

                        <!-- Delete Modal -->
                        <div class="modal fade" id="deleteOrder<?php echo $order['id'] . $table; ?>" tabindex="-1">
                            <div class="modal-dialog">
                                <div class="modal-content">
                                    <div class="modal-header">
                                        <h5 class="modal-title">Delete Order #<?php echo $order['id']; ?></h5>
                                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                                    </div>
                                    <div class="modal-body">
                                        <p>Are you sure you want to delete this order? This action cannot be undone.</p>
                                        <ul class="list-unstyled">
                                            <li><strong>Order ID:</strong> #<?php echo $order['id']; ?></li>
                                            <li><strong>Source:</strong> <?php echo ucfirst($table); ?></li>
                                            <li><strong>Phone:</strong> <?php echo htmlspecialchars($order['phone']); ?></li>
                                            <li><strong>Amount:</strong> $<?php echo number_format($order['prix'], 2); ?></li>
                                        </ul>
                                    </div>
                                    <div class="modal-footer">
                                        <form method="POST">
                                            <input type="hidden" name="action" value="delete_order">
                                            <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                            <input type="hidden" name="table" value="<?php echo $table; ?>">
                                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                                            <button type="submit" class="btn btn-danger">Delete Order</button>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endforeach; ?>
                        <?php if (empty($orders)): ?>
                        <tr>
                            <td colspan="9" class="text-center">No orders found</td>
                        </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- Pagination -->
            <?php if ($total_pages > 1): ?>
            <nav aria-label="Page navigation" class="mt-4">
                <ul class="pagination justify-content-center">
                    <li class="page-item <?php echo $page <= 1 ? 'disabled' : ''; ?>">
                        <a class="page-link" href="?table=<?php echo $table; ?>&page=<?php echo $page-1; ?>&search=<?php echo urlencode($search); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>">Previous</a>
                    </li>
                    <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                    <li class="page-item <?php echo $page === $i ? 'active' : ''; ?>">
                        <a class="page-link" href="?table=<?php echo $table; ?>&page=<?php echo $i; ?>&search=<?php echo urlencode($search); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>"><?php echo $i; ?></a>
                    </li>
                    <?php endfor; ?>
                    <li class="page-item <?php echo $page >= $total_pages ? 'disabled' : ''; ?>">
                        <a class="page-link" href="?table=<?php echo $table; ?>&page=<?php echo $page+1; ?>&search=<?php echo urlencode($search); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>">Next</a>
                    </li>
                </ul>
            </nav>
            <?php endif; ?>
        </div>
    </div>

</div> <!-- Close container from header -->

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html> 